"poly"An S4 class container for a polynomial description.
PList of length equal to the number of monomials. Each component is a vector of length equal to the polynomial degree. It contains the numbers of the variables in the monomial.
indicMatrix with as
many rows as monomials and as many columns as X-inputs.
The element (i,j) is 1 when the variable j
is in the monomial, 0 otherwise.
Objects from this class are usually not intended to be accessed directly by the end-user.
summary, print, or show: display functions.
print has an optional argument, all=FALSE.
When it is
set to TRUE, all the monomes are displayed. Otherwise, only
the polynomial
degree, the number of monomials and the number of variables.