"polyX"An S4 class container for a transformed dataset of inputs and its polynomial description.
Objects from this class are created by "new" or by the
functions vect2polyX, vect2polyXT,
crpolyX, crpolyXT
summary, print, show: display functions.
print has an optional argument, all=FALSE.
When it is
set to TRUE, all the monomes are displayed. Otherwise, only
the polynomial
degree, the number of monomials, the number of variables and
the number of observations.
bind: bind several polyX objects.
See bind.polyX