"sivip"An S4 class container for the result of the function
sivipm.
fo.isivipvector of length equal to the number of X-inputs. Individual sensitivity indices.
fo.isivip.percentsorted percentages of fo.isivip.
tsivipvector of length equal to the number of X-inputs. Total sensitivity indices.
tsivip.percentsorted percentages of tsivip.
monosignifa vector of length equal to the number of monomials.
correlaleaa matrix. The number of rows and columns is equal to the number of Y-inputs.
simca.signifcomponentsa matrix. The number of rows is equal to the number of components, and the number of columns is equal to the number of Y-inputs plus one.
lazraq.signifcomponentsa vector of length equal to the number of components.
outputa list which contains the additional results.
See description in the function
sivipm.
Objects from this class are created by the function
sivipm.
printdisplay function.
print has an optional argument, all=FALSE.
When it is
set to TRUE, all the components are displayed. Otherwise, the
slots fo.isivip, tsivip and
output are hidden.
showequivalent to print(all=TRUE)
summaryequivalent to print(all=FALSE)
getNamesdisplay the names of the non-null components